==> blancoMessage-0.4.0-src.zip: blancoMessage/blanco.python/main/blanco/sample/message/SampleMessage.py <==
# -*- coding: cp932 -*-
"""̃\[XR[h blanco FrameworkɂĎĂ܂B
"""
class SampleMessage:
    """bZ[W̃TvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B
    """

    """[bZ[W̃TvB̂PB]

    No.1:
    """
    MESSAGE001 = 'bZ[W̃TvB̂PB'

    """[bZ[Wu[{0}]u܂B]

    No.2:
    """
    MESSAGE002 = 'bZ[Wu[{0}]u܂B'

    """[bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]

    No.3:
    """
    MESSAGE003 = 'bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B'

    """[AbZ[Wu{0}{1}̗łB]

    No.4:
    """
    MESSAGE004 = 'AbZ[Wu{0}{1}̗łB'

    """[{0}擪u񂪂B]

    No.5:
    """
    MESSAGE005 = '{0}擪u񂪂B'

    """[Ōオu̗B{0}]

    No.6:
    """
    MESSAGE006 = 'Ōオu̗B{0}'

    """[xu{0}{1}{0}{1}{2}{1}{0}]

    No.7:
    """
    MESSAGE007 = 'xu{0}{1}{0}{1}{2}{1}{0}'

    """[̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]

    No.8:
    """
    MESSAGE008 = '̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B'

    """[{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]

    No.9:
    """
    MESSAGE009 = '{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB'

    """[GXP[v̊mFB_uNI[e[V&amp;quot;AVONI[e[V'AG}[N\B]

    No.10:
    """
    MESSAGE010 = 'GXP[v̊mFB_uNI[e[V"AVONI[e[V\'AG}[N\\B'

    """[~]

    No.11:
    """
    MESSAGE011 = '~'

    """[s[\n]̎B]

    No.12:
    """
    MESSAGE012 = 's[\n]̎B'

    def getMessage001(self):
        """bZ[W`ID[Sample]AL[[MESSAGE001]̕擾܂B

        No.1:
        [bZ[W̃TvB̂PB]

        self -- ̃\bh܂ރNXgB
        return -- bZ[WB
        """
        return 'bZ[W̃TvB̂PB'
    #end

    def getMessage002(self, arg0):
        """bZ[W`ID[Sample]AL[[MESSAGE002]̕擾܂B

        No.2:
        [bZ[Wu[{0}]u܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage002]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return 'bZ[Wu[' + arg0 + ']u܂B'
    #end

    def getMessage003(self, arg0, arg1):
        """bZ[W`ID[Sample]AL[[MESSAGE003]̕擾܂B

        No.3:
        [bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage003]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMessage003]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return 'bZ[Wu[' + arg0 + ']ɉAЂƂ[' + arg1 + ']u܂B'
    #end

    def getMessage004(self, arg0, arg1):
        """bZ[W`ID[Sample]AL[[MESSAGE004]̕擾܂B

        No.4:
        [AbZ[Wu{0}{1}̗łB]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage004]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMessage004]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return 'AbZ[Wu' + arg0 + arg1 + '̗łB'
    #end

    def getMessage005(self, arg0):
        """bZ[W`ID[Sample]AL[[MESSAGE005]̕擾܂B

        No.5:
        [{0}擪u񂪂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage005]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return arg0 + '擪u񂪂B'
    #end

    def getMessage006(self, arg0):
        """bZ[W`ID[Sample]AL[[MESSAGE006]̕擾܂B

        No.6:
        [Ōオu̗B{0}]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage006]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return 'Ōオu̗B' + arg0
    #end

    def getMessage007(self, arg0, arg1, arg2):
        """bZ[W`ID[Sample]AL[[MESSAGE007]̕擾܂B

        No.7:
        [xu{0}{1}{0}{1}{2}{1}{0}]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        arg2 -- u{2}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage007]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMessage007]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg2 is None:
            raise ValueError, "\bh[getMessage007]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return 'xu' + arg0 + arg1 + arg0 + arg1 + arg2 + arg1 + arg0
    #end

    def getMessage008(self, arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11):
        """bZ[W`ID[Sample]AL[[MESSAGE008]̕擾܂B

        No.8:
        [̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        arg2 -- u{2}̒lB
        arg3 -- u{3}̒lB
        arg4 -- u{4}̒lB
        arg5 -- u{5}̒lB
        arg6 -- u{6}̒lB
        arg7 -- u{7}̒lB
        arg8 -- u{8}̒lB
        arg9 -- u{9}̒lB
        arg10 -- u{10}̒lB
        arg11 -- u{11}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg2 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg3 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg4 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg4]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg5 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg5]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg6 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg6]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg7 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg7]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg8 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg8]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg9 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg9]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg10 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg10]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg11 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg11]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '̒uB' + arg11 + arg10 + arg9 + arg8 + arg7 + arg6 + arg5 + arg4 + arg3 + arg2 + arg1 + arg0 + '12B'
    #end

    def getMessage009(self, arg0, arg1):
        """bZ[W`ID[Sample]AL[[MESSAGE009]̕擾܂B

        No.9:
        [{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage009]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMessage009]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return arg0 + 'ԍԂƒu͕sƂĔf܂B' + arg1 + 'B̒`0IWłB'
    #end

    def getMessage010(self):
        """bZ[W`ID[Sample]AL[[MESSAGE010]̕擾܂B

        No.10:
        [GXP[v̊mFB_uNI[e[V&quot;AVONI[e[V'AG}[N\B]

        self -- ̃\bh܂ރNXgB
        return -- bZ[WB
        """
        return 'GXP[v̊mFB_uNI[e[V"AVONI[e[V\'AG}[N\\B'
    #end

    def getMessage011(self):
        """bZ[W`ID[Sample]AL[[MESSAGE011]̕擾܂B

        No.11:
        [~]

        self -- ̃\bh܂ރNXgB
        return -- bZ[WB
        """
        return '~'
    #end

    def getMessage012(self):
        """bZ[W`ID[Sample]AL[[MESSAGE012]̕擾܂B

        No.12:
        [s[\n]̎B]

        self -- ̃\bh܂ރNXgB
        return -- bZ[WB
        """
        return 's[' + "\n" + ']̎B'
    #end
#end

==> blancoMessage-0.6.3-src.zip: blancoMessage/blanco.python/main/blanco/sample/message/SampleMessage.py <==
# -*- coding: cp932 -*-
"""̃\[XR[h blanco FrameworkɂĎĂ܂B
"""
class SampleMessage:
    """bZ[W̃TvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B
    """

    """[bZ[W̃TvB̂PB]

    No.1:
    """
    MESSAGE001 = 'bZ[W̃TvB̂PB'

    """L[l: KEY_MESSAGE001

    No.1:
    """
    KEY_MESSAGE001 = 'MESSAGE001'

    """[bZ[Wu[{0}]u܂B]

    No.2:
    """
    MESSAGE002 = 'bZ[Wu[{0}]u܂B'

    """L[l: KEY_MESSAGE002

    No.2:
    """
    KEY_MESSAGE002 = 'MESSAGE002'

    """[bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]

    No.3:
    """
    MESSAGE003 = 'bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B'

    """L[l: KEY_MESSAGE003

    No.3:
    """
    KEY_MESSAGE003 = 'MESSAGE003'

    """[AbZ[Wu{0}{1}̗łB]

    No.4:
    """
    MESSAGE004 = 'AbZ[Wu{0}{1}̗łB'

    """L[l: KEY_MESSAGE004

    No.4:
    """
    KEY_MESSAGE004 = 'MESSAGE004'

    """[{0}擪u񂪂B]

    No.5:
    """
    MESSAGE005 = '{0}擪u񂪂B'

    """L[l: KEY_MESSAGE005

    No.5:
    """
    KEY_MESSAGE005 = 'MESSAGE005'

    """[Ōオu̗B{0}]

    No.6:
    """
    MESSAGE006 = 'Ōオu̗B{0}'

    """L[l: KEY_MESSAGE006

    No.6:
    """
    KEY_MESSAGE006 = 'MESSAGE006'

    """[xu{0}{1}{0}{1}{2}{1}{0}]

    No.7:
    """
    MESSAGE007 = 'xu{0}{1}{0}{1}{2}{1}{0}'

    """L[l: KEY_MESSAGE007

    No.7:
    """
    KEY_MESSAGE007 = 'MESSAGE007'

    """[̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]

    No.8:
    """
    MESSAGE008 = '̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B'

    """L[l: KEY_MESSAGE008

    No.8:
    """
    KEY_MESSAGE008 = 'MESSAGE008'

    """[{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]

    No.9:
    """
    MESSAGE009 = '{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB'

    """L[l: KEY_MESSAGE009

    No.9:
    """
    KEY_MESSAGE009 = 'MESSAGE009'

    """[GXP[v̊mFB_uNI[e[V&amp;quot;AVONI[e[V'AG}[N\B]

    No.10:
    """
    MESSAGE010 = 'GXP[v̊mFB_uNI[e[V"AVONI[e[V\'AG}[N\\B'

    """L[l: KEY_MESSAGE010

    No.10:
    """
    KEY_MESSAGE010 = 'MESSAGE010'

    """[~]

    No.11:
    """
    MESSAGE011 = '~'

    """L[l: KEY_MESSAGE011

    No.11:
    """
    KEY_MESSAGE011 = 'MESSAGE011'

    """[s[\n]̎B]

    No.12:
    """
    MESSAGE012 = 's[\n]̎B'

    """L[l: KEY_MESSAGE012

    No.12:
    """
    KEY_MESSAGE012 = 'MESSAGE012'

    def getMessage001(self):
        """bZ[W`ID[Sample]AL[[MESSAGE001]̕擾܂B

        No.1:
        [bZ[W̃TvB̂PB]

        self -- ̃\bh܂ރNXgB
        return -- bZ[WB
        """
        return 'bZ[W̃TvB̂PB'
    #end

    def getMessage002(self, arg0):
        """bZ[W`ID[Sample]AL[[MESSAGE002]̕擾܂B

        No.2:
        [bZ[Wu[{0}]u܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage002]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return 'bZ[Wu[' + arg0 + ']u܂B'
    #end

    def getMessage003(self, arg0, arg1):
        """bZ[W`ID[Sample]AL[[MESSAGE003]̕擾܂B

        No.3:
        [bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage003]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMessage003]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return 'bZ[Wu[' + arg0 + ']ɉAЂƂ[' + arg1 + ']u܂B'
    #end

    def getMessage004(self, arg0, arg1):
        """bZ[W`ID[Sample]AL[[MESSAGE004]̕擾܂B

        No.4:
        [AbZ[Wu{0}{1}̗łB]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage004]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMessage004]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return 'AbZ[Wu' + arg0 + arg1 + '̗łB'
    #end

    def getMessage005(self, arg0):
        """bZ[W`ID[Sample]AL[[MESSAGE005]̕擾܂B

        No.5:
        [{0}擪u񂪂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage005]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return arg0 + '擪u񂪂B'
    #end

    def getMessage006(self, arg0):
        """bZ[W`ID[Sample]AL[[MESSAGE006]̕擾܂B

        No.6:
        [Ōオu̗B{0}]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage006]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return 'Ōオu̗B' + arg0
    #end

    def getMessage007(self, arg0, arg1, arg2):
        """bZ[W`ID[Sample]AL[[MESSAGE007]̕擾܂B

        No.7:
        [xu{0}{1}{0}{1}{2}{1}{0}]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        arg2 -- u{2}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage007]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMessage007]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg2 is None:
            raise ValueError, "\bh[getMessage007]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return 'xu' + arg0 + arg1 + arg0 + arg1 + arg2 + arg1 + arg0
    #end

    def getMessage008(self, arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11):
        """bZ[W`ID[Sample]AL[[MESSAGE008]̕擾܂B

        No.8:
        [̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        arg2 -- u{2}̒lB
        arg3 -- u{3}̒lB
        arg4 -- u{4}̒lB
        arg5 -- u{5}̒lB
        arg6 -- u{6}̒lB
        arg7 -- u{7}̒lB
        arg8 -- u{8}̒lB
        arg9 -- u{9}̒lB
        arg10 -- u{10}̒lB
        arg11 -- u{11}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg2 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg3 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg4 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg4]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg5 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg5]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg6 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg6]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg7 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg7]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg8 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg8]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg9 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg9]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg10 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg10]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg11 is None:
            raise ValueError, "\bh[getMessage008]̃p[^[arg11]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '̒uB' + arg11 + arg10 + arg9 + arg8 + arg7 + arg6 + arg5 + arg4 + arg3 + arg2 + arg1 + arg0 + '12B'
    #end

    def getMessage009(self, arg0, arg1):
        """bZ[W`ID[Sample]AL[[MESSAGE009]̕擾܂B

        No.9:
        [{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMessage009]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMessage009]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return arg0 + 'ԍԂƒu͕sƂĔf܂B' + arg1 + 'B̒`0IWłB'
    #end

    def getMessage010(self):
        """bZ[W`ID[Sample]AL[[MESSAGE010]̕擾܂B

        No.10:
        [GXP[v̊mFB_uNI[e[V&quot;AVONI[e[V'AG}[N\B]

        self -- ̃\bh܂ރNXgB
        return -- bZ[WB
        """
        return 'GXP[v̊mFB_uNI[e[V"AVONI[e[V\'AG}[N\\B'
    #end

    def getMessage011(self):
        """bZ[W`ID[Sample]AL[[MESSAGE011]̕擾܂B

        No.11:
        [~]

        self -- ̃\bh܂ރNXgB
        return -- bZ[WB
        """
        return '~'
    #end

    def getMessage012(self):
        """bZ[W`ID[Sample]AL[[MESSAGE012]̕擾܂B

        No.12:
        [s[\n]̎B]

        self -- ̃\bh܂ރNXgB
        return -- bZ[WB
        """
        return 's[' + "\n" + ']̎B'
    #end
#end
